Index: geos/include/geos/planargraph/DirectedEdgeStar.h
===================================================================
--- geos.orig/include/geos/planargraph/DirectedEdgeStar.h	2013-12-06 13:44:31.720065393 +0100
+++ geos/include/geos/planargraph/DirectedEdgeStar.h	2013-12-06 13:44:31.716065384 +0100
@@ -19,6 +19,7 @@
 #include <geos/export.h>
 
 #include <vector>
+#include <cstddef>
 
 #ifdef _MSC_VER
 #pragma warning(push)
@@ -39,6 +40,8 @@
 namespace geos {
 namespace planargraph { // geos.planargraph
 
+using namespace std;
+
 /// A sorted collection of DirectedEdge which leave a Node in a PlanarGraph.
 class GEOS_DLL DirectedEdgeStar {
 protected:
